@@ -20,13 +20,6 @@ module.exports = generators.Base.extend({
     this.argument('appName', { type: String, required: false });
     this.option('appName', { type: String, required: false });
     this.option('appId', { type: String, required: false });
-    this.option('compass', { type: Boolean, required: false });
-    this.option('starter', { type: String, required: false });
-    /*this.option('templates', { type: Array, required: false });
-    this.option('plugins', { type: Object, required: false });*/
-    this.option('auth', { type: Object, required: false });
-    /*this.option('flurry', { type: Object, required: false });
-    this.option('push', { type: Object, required: false });*/
     this.options.selected = {};
     this.lplugins = [];
     this.scriptsFile = [];
@@ -40,20 +33,20 @@ module.exports = generators.Base.extend({
         type: 'confirm',
         name: 'compass',
         message: 'Would you like to use Sass with Compass (requires Ruby)?',
-        default: (typeof(this.options.compass) !== 'undefined') ? this.options.compass : false
+        default: true
       }], function (props) {
-        this.compass = this.options.selected.compass = props.compass;
+        this.compass = props.compass;
 
         done();
       }.bind(this));
     },
-    askForRoutes: function() { ionicUtils.routes.ask(this) },
-    askForModels: function() { ionicUtils.models.ask(this) },
-    askForAuthentificationProvider: function() { ionicUtils.auth.ask(this) },
-    /*
-    askForAnalytics: function() { ionicUtils.analytics.ask(this) },
-    askForPush: function() { ionicUtils.push.ask(this) },
-    askForPlugins: { ionicUtils.plugins.ask(this) },*/
+    askForRoutes: function() { ionicUtils.routes.ask(this); },
+    askForModels: function() { ionicUtils.models.ask(this); },
+    askForAuthProvider: function() { ionicUtils.auth.ask(this); },
+    askForAnalytics: function() { ionicUtils.analytics.ask(this); },
+    askForPush: function() { ionicUtils.push.ask(this); },
+    askForPlugins: function() { ionicUtils.plugins.ask(this); },
+    askForGrunt: function() { ionicUtils.grunt.ask(this); },
     askForStarter: function askForStarter() {
       var done = this.async();
 
@@ -130,7 +123,8 @@ module.exports = generators.Base.extend({
       this.template('common/_bower.json', 'bower.json');
       this.template('common/_bowerrc', '.bowerrc');
       this.template('common/_package.json', 'package.json');
-      this.copy('common/_Gruntfile.js', 'Gruntfile.js');
+      if (this.grunt)
+        this.copy('common/_Gruntfile.js', 'Gruntfile.js');
       this.template('common/_gitignore', '.gitignore');
     }
   },
@@ -153,10 +147,11 @@ module.exports = generators.Base.extend({
     installModels: function installModels() { ionicUtils.models.install(this); },
     installRoutes: function installRoutes() { ionicUtils.routes.install(this); },
     installAuthProvider: function installAuthProvider() { ionicUtils.auth.install(this); },
-    /*installPush: function installPush() { ionicUtils.push.install(this); },
+    installPush: function installPush() { ionicUtils.push.install(this); },
     installFlurry: function installFlurry() { ionicUtils.analytics.install(this); },
     installPlugins: function installPlugins()  { ionicUtils.plugins.install(this); },
-  */
+    installGrunt: function installAuthProvider() { ionicUtils.grunt.install(this); },
+    
     installStarter: function installStarter() {
       console.log(chalk.yellow('Installing starter template. Please wait'));
       var done = this.async();
@@ -269,6 +264,7 @@ module.exports = generators.Base.extend({
     },
 
     cordovaHooks: function cordovaHooks() {
+      // copy hooks directory
       this.directory('hooks', 'hooks', true);
     },
 
@@ -287,12 +283,10 @@ module.exports = generators.Base.extend({
       fs.rename(path.join(appPath, 'css'), path.join(appPath, 'styles'), function(err) {
           if ( err ) console.log('ERROR: ' + err);
       });
-      
       // Rename: CSS path (Ionics 'css' to 'styles')
       fs.rename(path.join(appPath, 'js'), path.join(appPath, 'scripts'), function(err) {
           if ( err ) console.log('ERROR: ' + err);
-      });
-      
+      });     
       // Rename: Images path (Ionics 'img' to 'images')
       fs.rename(path.join(appPath, 'img'), path.join(appPath, 'images'), function(err) {
           if ( err ) console.log('ERROR: ' + err);
