@@ -3,7 +3,7 @@ angular.module('{{APP_NAME}}.services').factory('AuthService', [
   '$q',
   '$resource',
   {{AUTH_PROVIDERS_QUOTED}}
-  function ($q, $resource, {{AUTH_PROVIDERS}}) {
+  function ($q, $resource {{AUTH_PROVIDERS}}) {
     var authenticateRequests = {
       'login': $resource('https://api.parse.com/1/login').get,
       'signup': $resource('https://api.parse.com/1/users').post
