@@ -2,6 +2,8 @@
 var path = require('path');
 
 var createService = function(self, provider) {
+  if (provider == 'facebook')
+    self.facebook = true;
   var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
   file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
   var fileName = provider+'Service.js';
